Index: base/trace_event/process_memory_dump.h |
diff --git a/base/trace_event/process_memory_dump.h b/base/trace_event/process_memory_dump.h |
index 4f7d141104dd3342a26c3263aa2686bf1f20eb5f..58209bc1dfcf7393c8b47247e3d81219b8d4800c 100644 |
--- a/base/trace_event/process_memory_dump.h |
+++ b/base/trace_event/process_memory_dump.h |
@@ -48,11 +48,15 @@ class BASE_EXPORT ProcessMemoryDump { |
SmallMap<hash_map<std::string, MemoryAllocatorDump*>>; |
#if defined(COUNT_RESIDENT_BYTES_SUPPORTED) |
- // Returns the total bytes resident for a virtual address range, with given |
- // |start_address| and |mapped_size|. |mapped_size| is specified in bytes. The |
- // value returned is valid only if the given range is currently mmapped by the |
- // process. The |start_address| must be page-aligned. |
- static size_t CountResidentBytes(void* start_address, size_t mapped_size); |
+ // Counts the total bytes resident for a virtual address range, with given |
+ // |start_address| and |mapped_size| and sets |resident_size|. |mapped_size| |
+ // is specified in bytes. The value returned is valid only if the given range |
+ // is currently mmapped by the process. The |start_address| must be |
+ // page-aligned. |
+ // Returns true on success. |
+ static bool CountResidentBytes(void* start_address, |
+ size_t mapped_size, |
+ size_t* resident_size); |
#endif |
ProcessMemoryDump(const scoped_refptr<MemoryDumpSessionState>& session_state); |